@@ -1,7 +1,7 @@
 # -*- shell-script -*-
 # debugger command options processing. The bane of programming.
 #
-#   Copyright (C) 2008-2012, 2014-2017 Rocky Bernstein <rocky@gnu.org>
+#   Copyright (C) 2008-2012, 2014-2018 Rocky Bernstein <rocky@gnu.org>
 #
 #   This program is free software; you can redistribute it and/or
 #   modify it under the terms of the GNU General Public License as
@@ -48,6 +48,7 @@ options:
     -S | --style STYLE       Run use pygments STYLE for formatting source code
     --tty | --terminal DEV   Set to terminal in debugger output to DEV
                              DEV can also be &1 for STDOUT
+    --tty_in | --terminal_in DEV   Set to ...
     -T | --tempdir DIRECTORY
                              Use DIRECTORY to store temporary files
     -V | --version           Print the debugger version number.
@@ -94,7 +95,7 @@ fi
 
 typeset -ix _Dbg_working_term_highlight
 
-if ${_Dbg_libdir}/lib/term-highlight.py -V 2>/dev/null  1>/dev/null ; then
+if "${_Dbg_libdir}/lib/term-highlight.py" -V 2>/dev/null  1>/dev/null ; then
     _Dbg_working_term_highlight=1
 else
     _Dbg_working_term_highlight=0
@@ -102,34 +103,34 @@ fi
 
 typeset -x _Dbg_set_style=''
 # $_Dbg_tmpdir could have been set by the top-level debugger script.
-[[ -z $_Dbg_tmpdir ]] && typeset _Dbg_tmpdir=/tmp
+[[ -z "$_Dbg_tmpdir" ]] && typeset _Dbg_tmpdir=/tmp
 
 _Dbg_check_tty() {
     (( $# < 1 )) && return 1
     typeset tty=$1
     if [[ $tty != '&1' ]] ; then
-        if ! $(touch $tty >/dev/null 2>/dev/null); then
+        if ! $(touch "$tty" >/dev/null 2>/dev/null); then
             _Dbg_errmsg "Can't access $tty for writing."
             return 1
         fi
-        if [[ ! -w $tty ]] ; then
+        if [[ ! -w "$tty" ]] ; then
             _Dbg_errmsg "tty $tty needs to be writable"
             return 1
         fi
-        _Dbg_tty=$tty
-        _Dbg_prompt_output=$_Dbg_tty
+        _Dbg_tty="$tty"
+        _Dbg_prompt_output="$_Dbg_tty"
     fi
     return 0
 }
 
 _Dbg_parse_options() {
 
-    . ${_Dbg_libdir}/getopts_long.sh
+    . "${_Dbg_libdir}/getopts_long.sh"
 
     typeset -i _Dbg_o_quiet=0
     typeset -i _Dbg_o_version=0
 
-    while getopts_long A:Bc:x:hL:nqTt:VX opt \
+    while getopts_long A:Bc:x:hL:nqTt:Yy:VX opt \
         annotate     required_argument       \
         basename     no_argument             \
         command      required_argument       \
@@ -146,6 +147,8 @@ _Dbg_parse_options() {
         tempdir      required_argument       \
         tty          required_argument       \
         terminal     required_argument       \
+        tty_in       required_argument       \
+        terminal_in  required_argument       \
         version      no_argument             \
         '' "$@"
     do
@@ -167,12 +170,12 @@ _Dbg_parse_options() {
 			_Dbg_set_highlight=$OPTLARG
 		    ;;
 		* )
-		    print "Expecting 'dark' or 'light', got \"${OPTLARG}\"" >&2
+		    printf "Expecting 'dark' or 'light', got \"${OPTLARG}\"" >&2
 		    exit 2
 		esac
 
-		if (( ! _Dbg_have_working pygmentize )) ; then
-                    print "Can't run pygmentize. --highight forced off" >&2
+		if (( ! _Dbg_have_working_pygmentize )) ; then
+                    printf "Can't run pygmentize. --highlight forced off" >&2
 		    _Dbg_set_highlight=''
                 fi
                 ;;
@@ -193,12 +196,15 @@ _Dbg_parse_options() {
             tempdir)
                 _Dbg_tmpdir=$OPTLARG    ;;
             terminal | tty )
-                if _Dbg_check_tty $OPTLARG ; then
-                    _Dbg_tty=$OPTLARG
+                if _Dbg_check_tty "$OPTLARG" ; then
+                    _Dbg_tty="$OPTLARG"
                 else
                     _Dbg_errmsg '--tty option ignored'
                 fi
                 ;;
+            terminal_in | tty_in )
+                _Dbg_tty_in="$OPTLARG"
+                ;;
             x | eval-command )
                 DBG_INPUT=$OPTLARG      ;;
             X | trace )
@@ -220,7 +226,7 @@ _Dbg_parse_options() {
         [[ -n $_Dbg_release ]] ; then
         echo "$_Dbg_shell_name debugger, $_Dbg_debugger_name, release $_Dbg_release"
         printf '
-Copyright 2002-2004, 2006-2012, 2014, 2016-2017 Rocky Bernstein
+Copyright 2002-2004, 2006-2012, 2014, 2016-2018 Rocky Bernstein
 This is free software, covered by the GNU General Public License, and you are
 welcome to change it and/or distribute copies of it under certain conditions.
 
@@ -248,7 +254,7 @@ welcome to change it and/or distribute copies of it under certain conditions.
 if (( _Dbg_have_working_pygmentize )) && [[ -z "$_Dbg_set_highlight" ]] ; then
     # Honor DARK_BG if already set. If not set, set it.
     if [[ -z "$DARK_BG" ]] ; then
-	. ${_Dbg_libdir}/init/term-background.sh >/dev/null
+	. "${_Dbg_libdir}/init/term-background.sh" >/dev/null
     fi
 
     # DARK_BG is now either 0 or 1.
