@@ -1,7 +1,7 @@
 # -*- shell-script -*-
 # filecache.sh - cache file information
 #
-#   Copyright (C) 2008-2011, 2013-2015 Rocky Bernstein
+#   Copyright (C) 2008-2011, 2013-2015, 2018 Rocky Bernstein
 #   <rocky@gnu.org>
 #
 #   This program is free software; you can redistribute it and/or
@@ -126,7 +126,9 @@ function _Dbg_is_file {
     echo ''
     return 1
   fi
-  typeset find_file="$1"
+  # first character might be encoded as \057 == '/',
+  # find_file:0:1 == "\" , true story
+  typeset find_file="$(printf "$1")"
   typeset try_find_file
 
   if [[ -z $find_file ]] ; then
@@ -199,14 +201,14 @@ function _Dbg_readin {
     typeset source_array
     typeset -ri NOT_SMALLFILE=1000
 
-    if [[ -z $filename ]] || [[ $filename == "$_Dbg_bogus_file" ]] ; then
-	eval "${_Dbg_source_array_var}[0]=\"$Dbg_EXECUTION_STRING\""
-  else
+    if [[ -z "$filename" ]] || [[ "$filename" == "$_Dbg_bogus_file" ]] ; then
+	  eval "${_Dbg_source_array_var}[0]=\"$Dbg_EXECUTION_STRING\""
+    else
 	fullname=$(_Dbg_resolve_expand_filename "$filename")
-	if [[ -r $fullname ]] ; then
+	if [[ -r "$fullname" ]] ; then
 	    typeset -r progress_prefix="Reading $filename"
-	    _Dbg_file2canonic[$filename]="$fullname"
-	    _Dbg_file2canonic[$fullname]="$fullname"
+	    _Dbg_file2canonic["$filename"]="$fullname"
+	    _Dbg_file2canonic["$fullname"]="$fullname"
 	    # Use readarray which speeds up reading greatly.
 	    typeset -ri BIGFILE=30000
 	    if wc -l < /dev/null >/dev/null 2>&1 ; then
@@ -230,7 +232,7 @@ function _Dbg_readin {
 			-C "_Dbg_progess_show \"${progress_prefix}\" ${line_count}" \
 			$_Dbg_highlight_array_var < "$tempfile"
 		fi
-		[[ -r $tempfile ]] && rm $tempfile
+		[[ -r "$tempfile" ]] && rm "$tempfile"
 	    fi
 	    (( line_count > BIGFILE)) && _Dbg_progess_done
 	else
@@ -238,13 +240,10 @@ function _Dbg_readin {
 	fi
     fi
 
-    typeset -r line_count_cmd="line_count=\${#${_Dbg_source_array_var[@]}}"
-    eval $line_count_cmd
-
     (( line_count >= NOT_SMALLFILE )) && _Dbg_msg "done."
 
     # Add $filename to list of all filenames
-    _Dbg_filenames[$fullname]=$_Dbg_source_array_var;
+    _Dbg_filenames["$fullname"]=$_Dbg_source_array_var;
     return 0
 }
 
@@ -259,7 +258,7 @@ _Dbg_readin_if_new() {
 	typeset rc=$?
 	set +xv
 	(( $? != 0 )) && return $rc
-	[[ -z $fullname ]] && return 1
+	[[ -z "$fullname" ]] && return 1
 	_Dbg_set_source_array_var "$filename" || return $?
     fi
     return 0
@@ -271,17 +270,17 @@ _Dbg_readin_if_new() {
 _Dbg_set_source_array_var() {
     (( $# != 1 )) && return 1
     typeset filename="$1"
-    [[ -z $filename ]] && return 2
-    fullname=${_Dbg_file2canonic[$filename]}
-    [[ -z $fullname ]] && [[ -n ${_Dbg_filenames[$filename]} ]] && {
+    [[ -z "$filename" ]] && return 2
+    fullname="${_Dbg_file2canonic["$filename"]}"
+    [[ -z "$fullname" ]] && [[ -n "${_Dbg_filenames["$filename"]}" ]] && {
 	fullname="$filename"
     }
-    [[ -z $fullname ]] && return 2
-    _Dbg_source_array_var=${_Dbg_filenames[$fullname]}
+    [[ -z "$fullname" ]] && return 2
+    _Dbg_source_array_var=${_Dbg_filenames["$fullname"]}
     if [[ -n $_Dbg_set_highlight ]] ; then
 	_Dbg_highlight_array_var="${_Dbg_source_array_var/_Dbg_source_/_Dbg_highlight_}"
     fi
-    _Dbg_source_array_var=${_Dbg_filenames[$fullname]}
+    _Dbg_source_array_var=${_Dbg_filenames["$fullname"]}
     [[ -z $_Dbg_source_array_var ]] && return 2
     return 0
 }
