@@ -17,7 +17,7 @@ test_preserve_set_opts()
 	# Name we refer to ourselves by
 	typeset _Dbg_debugger_name='bashdb'
 	# The release name we are configured to run under.
-	typeset _Dbg_release='4.4-0.94'
+	typeset _Dbg_release='4.4-1.0.1'
 	. ${top_builddir}/bashdb-trace -L $libdir
 	assertEquals $old_opts $-
     else
