@@ -23,10 +23,10 @@ test_pre_do_show_version()
     # Name we refer to ourselves by
     typeset _Dbg_debugger_name='bashdb'
     # The release name we are configured to run under.
-    typeset _Dbg_release='4.4-0.94'
+    typeset _Dbg_release='4.4-1.0.1'
 
     version_string=$(_Dbg_do_show_version 2>&1)
-    assertEquals "bashdb, release 4.4-0.94" "$version_string"
+    assertEquals "bashdb, release 4.4-1.0.1" "$version_string"
 }
 abs_top_srcdir=/src/external-vcs/sourceforge/bashdb
 # Make sure $abs_top_srcdir has a trailing slash
