@@ -7,7 +7,9 @@ test_save_restore_IFS_PS4()
 {
     typeset  _Dbg_space_IFS=' '
     typeset old_IFS="$IFS"
+    typeset _Dbg_old_set_opts=$-
     typeset new_ifs=' 	'
+    _Dbg_old_set_nullglob=1
     IFS="$new_ifs"
     PS4='123'
     _Dbg_set_debugger_entry
@@ -19,18 +21,15 @@ test_save_restore_IFS_PS4()
     IFS="$old_IFS"
 }
 
-abs_top_srcdir=/src/external-vcs/bashdb-3.1
-srcdir=.
-
-_Dbg_libdir=$abs_top_srcdir
-set -- -q  # Don't need to show banner
-. ${abs_top_srcdir}/dbg-pre.sh
+abs_top_srcdir=/src/external-vcs/sourceforge/bashdb
+# Make sure $abs_top_srcdir has a trailing slash
+abs_top_srcdir=${abs_top_srcdir%%/}/
+. ${abs_top_srcdir}test/unit/helper.sh
+. ${abs_top_srcdir}/init/pre.sh
 . ${abs_top_srcdir}/lib/journal.sh
-. ${abs_top_srcdir}/lib/fns.sh
+. ${abs_top_srcdir}/lib/filecache.sh
 . ${abs_top_srcdir}/lib/file.sh
 . ${abs_top_srcdir}/lib/save-restore.sh
+set -- # reset $# so shunit2 doesn't get confused.
 
-# load shunit2
-srcdir=.
-srcdir=${srcdir}/
-. ${srcdir}/shunit2
+[[ $0 == ${BASH_SOURCE} ]] && . ${shunit_file}
